@@ -1,15 +1,16 @@
 ## File Name: conf.detect.R
-## File Version: 1.08
+## File Version: 1.16
 
 
-#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 # Confirmatory DETECT analysis
 conf.detect <- function( data, score, itemcluster, bwscale=1.1, progress=TRUE,
-                            thetagrid=seq( -3,3,len=200)  ){
+                        thetagrid=seq( -3,3,len=200))
+{
     CALL <- match.call()
     cat("-----------------------------------------------------------\n" )
-    cat("Confirmatory DETECT Analysis \n" ) ; flush.console()
-    h1 <- is.matrix( score )
+    cat("Confirmatory DETECT Analysis \n" )
+    utils::flush.console()
+    h1 <- is.matrix(score)
     if (h1){
         PP <- ncol(score)
     }
@@ -24,7 +25,7 @@ conf.detect <- function( data, score, itemcluster, bwscale=1.1, progress=TRUE,
     utils::flush.console()
     if ( ! h1 ){
         ccovtable <- ccov.np( data, score=score, bwscale=bwscale,
-                                progress=progress, thetagrid=thetagrid )
+                            progress=progress, thetagrid=thetagrid )
         res <- detect.index( ccovtable, itemcluster=itemcluster )
     } else {
         ccovtable.list <- list()
@@ -32,25 +33,26 @@ conf.detect <- function( data, score, itemcluster, bwscale=1.1, progress=TRUE,
             cat( paste( "DETECT Calculation Score ", pp, "\n", sep="") ) ;
             utils::flush.console()
             ccovtable.list[[pp]] <- ccov.np( data, score=score[,pp],
-                                    bwscale=bwscale, progress=FALSE )
+                                        bwscale=bwscale, progress=FALSE )
         }
         detect.list <- lapply( ccovtable.list, FUN=function( ccovtable ){
                     detect.index( ccovtable, itemcluster=itemcluster ) } )
-        detect.matrix <- matrix( unlist( lapply( detect.list, FUN=function( ll){ c( ll[1,], ll[2,], ll[3,] ) } ) ), nrow=PP, byrow=T)
+        detect.matrix <- matrix( unlist( lapply( detect.list, FUN=function( ll){
+                                c( ll[1,], ll[2,], ll[3,] ) } ) ), nrow=PP, byrow=TRUE)
         detect.summary <- data.frame( "NScores"=PP, "Mean"=colMeans( detect.matrix ),
-                    "SD"=apply( detect.matrix, 2, stats::sd ),
-                    "Min"=apply( detect.matrix, 2, min ),
-                    "Max"=apply( detect.matrix, 2, max )
-                    )
+                                "SD"=apply( detect.matrix, 2, stats::sd ),
+                                "Min"=apply( detect.matrix, 2, min ),
+                                "Max"=apply( detect.matrix, 2, max )
+                )
         rownames(detect.summary) <- c("DETECT Unweighted", "DETECT Weighted", "ASSI Unweighted", "ASSI Weighted",
-                        "RATIO Unweighted", "RATIO Weighted" )
+                    "RATIO Unweighted", "RATIO Weighted" )
     }
     cat("-----------------------------------------------------------\n" )
     if ( ! h1){
-        res <- list(  "detect"=res, "ccovtable"=ccovtable,
+        res <- list( "detect"=res, "ccovtable"=ccovtable,
                     "detect.summary"=res )
     } else {
-        res <- list(  "detect"=detect.list, "ccovtable"=ccovtable.list,
+        res <- list( "detect"=detect.list, "ccovtable"=ccovtable.list,
             "detect.summary"=detect.summary )
     }
     res$is_one_score <- is_one_score
@@ -63,5 +65,4 @@ conf.detect <- function( data, score, itemcluster, bwscale=1.1, progress=TRUE,
     class(res) <- "conf.detect"
     return(res)
 }
-#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
